climind.fetchers package
========================

Submodules
----------

climind.fetchers.fetcher\_cds module
------------------------------------

.. automodule:: climind.fetchers.fetcher_cds
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_cmems\_ftp module
-------------------------------------------

.. automodule:: climind.fetchers.fetcher_cmems_ftp
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_ersst module
--------------------------------------

.. automodule:: climind.fetchers.fetcher_ersst
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_ftp module
------------------------------------

.. automodule:: climind.fetchers.fetcher_ftp
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_grace module
--------------------------------------

.. automodule:: climind.fetchers.fetcher_grace
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_jra55\_grid module
--------------------------------------------

.. automodule:: climind.fetchers.fetcher_jra55_grid
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_no\_url module
----------------------------------------

.. automodule:: climind.fetchers.fetcher_no_url
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_noaaglobaltemp module
-----------------------------------------------

.. automodule:: climind.fetchers.fetcher_noaaglobaltemp
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_promice module
----------------------------------------

.. automodule:: climind.fetchers.fetcher_promice
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_standard\_url module
----------------------------------------------

.. automodule:: climind.fetchers.fetcher_standard_url
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_url\_with\_backsearch module
------------------------------------------------------

.. automodule:: climind.fetchers.fetcher_url_with_backsearch
   :members:
   :undoc-members:
   :show-inheritance:

climind.fetchers.fetcher\_utils module
--------------------------------------

.. automodule:: climind.fetchers.fetcher_utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: climind.fetchers
   :members:
   :undoc-members:
   :show-inheritance:
